@@ -1,5 +1,5 @@
-##### SOM algorithm functions
-################################################################################
+## SOM algorithm functions
+## ----------------------------------------------------------------------------
 
 ##### Auxiliary functions
 ################################################################################
@@ -456,6 +456,112 @@ calculateEnergy <- function(x.data, clustering, prototypes, parameters, ind.t) {
 
 ##### Main function
 ################################################################################
+
+#' @title Run the SOM algorithm
+#' @export
+#' @name trainSOM
+#' @exportClass somRes
+#' 
+#' @description The \code{trainSOM} function returns a \code{somRes} class 
+#' object which contains the outputs of the algorithm.
+#' 
+#' @aliases summary.somRes
+#' @aliases print.somRes
+#' 
+#' @param x.data a data frame or matrix containing the observations to be mapped
+#' on the grid by the SOM algorithm.
+#' @param \dots Further arguments to be passed to the function 
+#' \code{\link{initSOM}} for specifying the parameters of the algorithm. The 
+#' default values of the arguments \code{maxit} and \code{dimension} are 
+#' calculated according to the SOM type if the user does not set them:
+#' \itemize{
+#'   \item \code{maxit} is equal to (number of rows+number of columns)*5 if the 
+#'   SOM type is \code{korresp}. It is equal to number of rows*5 in all other 
+#'   SOM types
+#'   \item \code{dimension}: for a \code{korresp} SOM, is approximately equal to
+#'   the square root of the number of observations to be classified divided by
+#'   10 but it is never smaller than 5 or larger than 10.
+#' }
+#' @param x an object of class \code{somRes}.
+#' @param object an object of class \code{somRes}.
+#' 
+#' @return The \code{trainSOM} function returns an object of class \code{somRes}
+#' which contains the following components:
+#' \itemize{
+#'   \item{clustering}{the final classification of the data.}
+#'   \item{prototypes}{the final coordinates of the prototypes.}
+#'   \item{energy}{the final energy of the map.}
+#'   \item{backup}{a list containing some intermediate backups of the prototypes
+#'   coordinates, clustering, energy and the indexes of the recorded backups, if
+#'   \code{nb.save} is set to a value larger than 1.}
+#'   \item{data}{the original dataset used to train the algorithm.}
+#'   \item{parameters}{a list of the map's parameters, which is an object of 
+#'   class \code{paramSOM} as produced by the function \code{\link{initSOM}}.}
+#' }
+#' The function \code{summary.somRes} also provides an ANOVA (ANalysis Of 
+#' VAriance) of each input numeric variables in function of the map's clusters. 
+#' This is helpful to see which variables participate to the clustering.
+#' 
+#' @details The version of the SOM algorithm implemented in this package is the
+#' stochastic version.
+#' 
+#' Several variants able to handle non-vectorial data are also implemented in 
+#' their stochastic versions: \code{type="korresp"} for contingency tables, as
+#' described in Cottrell et al., 2004 (with weights as in Cottrel and Letremy, 
+#' 2005); \code{type="relational"} for dissimilarity matrices, as described in
+#' Olteanu et al., 2015, with the fast implementation introduced in Mariette
+#' \emph{et al.}, 2017.
+#' 
+#' \code{summary} produces a complete summary of the results that displays the 
+#' parameters of the SOM, quality criteria and ANOVA. For \code{type="numeric"}
+#' the ANOVA is performed for each input variable and test the difference of 
+#' this variable accross the clsuters of the map. For \code{type="relational"} a
+#' dissimilarity ANOVA is performed (see (Anderson, 2001), except that in the 
+#' present version, a crude estimate of the p-value is used which is based on 
+#' the Fisher distribution and not on a permutation test.
+#' 
+#' @references 
+#' Anderson M.J. (2001). A new method for non-parametric multivariate analysis 
+#' of variance. \emph{Austral Ecology}, \strong{26}, 32-46. 
+#' 
+#' Kohonen T. (2001) \emph{Self-Organizing Maps}. Berlin/Heidelberg: 
+#' Springer-Verlag, 3rd edition.
+#' 
+#' Cottrell M., Ibbou S., Letremy P. (2004) SOM-based algorithms for qualitative
+#' variables. \emph{Neural Networks}, \strong{17}, 1149-1167.
+#' 
+#' Cottrell M., Letremy P. (2005) How to use the Kohonen algorithm to 
+#' simultaneously analyse individuals in a survey. \emph{Neurocomputing}, 
+#' \strong{21}, 119-138.
+#' 
+#' Olteanu M., Villa-Vialaneix N. (2015) On-line relational and multiple
+#' relational SOM. \emph{Neurocomputing}, \strong{147}, 15-30. 
+#' 
+#' Mariette J., Rossi F., Olteanu M., Mariette J. (2017) Accelerating stochastic 
+#' kernel SOM. In: M. Verleysen, \emph{XXVth European Symposium on Artificial 
+#' Neural Networks, Computational Intelligence and Machine Learning 
+#' (ESANN 2017)}, i6doc, Bruges, Belgium, 269-274.
+#' 
+#' @author Jérome Mariette \email{jerome.mariette@inrae.fr}\cr
+#' Madalina Olteanu \email{madalina.olteanu@univ-paris1.fr}\cr
+#' Fabrice Rossi \email{fabrice.rossi@apiacoa.org}\cr
+#' Nathalie Vialaneix \email{nathalie.vialaneix@inrae.fr}
+#'
+#' @note Warning! Recording intermediate backups with the argument 
+#' \code{nb.save} can strongly increase the computational time since calculating
+#' the entire clustering and the energy is time consumming. Use this option with
+#' care and only when it is strictly necessary.
+#' 
+#' @seealso See \code{\link{initSOM}} for a description of the paramaters to 
+#' pass to the trainSOM function to change its behavior and 
+#' \code{\link{plot.somRes}} to plot the outputs of the algorithm.
+#' 
+#' @examples 
+#' # Run trainSOM algorithm on the iris data with 500 iterations
+#' iris.som <- trainSOM(x.data=iris[,1:4])
+#' iris.som
+#' summary(iris.som)
+
 trainSOM <- function (x.data, ...) {
   param.args <- list(...)
   ## Step 1: Parameters handling
@@ -746,6 +852,8 @@ projectGraph <- function(the.graph, clustering, coord.clustering) {
 ## S3 methods for somRes class objects
 ################################################################################
 
+#' @export
+#' @rdname trainSOM
 print.somRes <- function(x, ...) {
   cat("      Self-Organizing Map object...\n")
   cat("        ", x$parameters$mode, "learning, type:", x$parameters$type,"\n")
@@ -756,6 +864,8 @@ print.somRes <- function(x, ...) {
   cat("         distance type:", x$parameters$the.grid$dist.type,"\n")
 }
 
+#' @export
+#' @rdname trainSOM
 summary.somRes <- function(object, ...) {
   cat("\nSummary\n\n")
   cat("      Class : ", class(object),"\n\n")
@@ -785,6 +895,7 @@ summary.somRes <- function(object, ...) {
     cat("\n")
   } else if (object$parameters$type=="korresp") {
     chisq.res <- chisq.test(object$data)
+    sig <- ""
     if (chisq.res$p.value<0.05) sig <- "*"
     if (chisq.res$p.value<0.01) sig <- "**"
     if (chisq.res$p.value<0.001) sig <- "***"
@@ -808,6 +919,7 @@ summary.somRes <- function(object, ...) {
       ((nrow(norm.data)-n.clusters)/(n.clusters-1))
     
     p.value <- 1-pf(F.stat, n.clusters-1, nrow(norm.data)-n.clusters)
+    sig <- ""
     if (p.value<0.001) {
       sig <- "***"
     } else if (p.value<0.1) {
@@ -862,6 +974,45 @@ predictRSOM <- function(object, x.new=NULL, radius=0, tolerance=10^(-10),
   return(winners)
 }
 
+#' @title Predict the classification of a new observation
+#' @export
+#' @name predict.somRes
+#' 
+#' @description Predict the neuron where a new observation is classified
+#' 
+#' @param object a \code{somRes} object.
+#' @param x.new a new observation (optional). Default values is NULL which
+#' corresponds to performing prediction on the training dataset.
+#' @param \dots not used.
+#' @param radius current radius used to perform soft affectation (when 
+#' \code{affectation="heskes"}, see \code{\link{initSOM}} for further details
+#' about Heskes's soft affectation). Default value is \option{0}, 
+#' which corresponds to a hard affectation.
+#' @param tolerance numeric tolerance (to avoid numeric instability during 
+#' 'cosine' pre-processing). Default value is \option{10^(-10)}
+#' 
+#' @details The number of columns of the new observations (or its length if only 
+#' one observation is provided) must match the number of colums of the data set
+#' given to the SOM algorithm (see \code{\link{trainSOM}}).
+#' 
+#' @return \code{predict.somRes} returns the number of the neuron to which the 
+#' new observation is assigned (i.e., neuron with the closest prototype).
+#' 
+#' When the algorithm's type is \code{"korresp"}, \code{x.new} must be the 
+#' original contingency table passed to the algorithm.
+#' 
+#' @author Jérome Mariette \email{jerome.mariette@inrae.fr}\cr
+#' Madalina Olteanu \email{madalina.olteanu@univ-paris1.fr}\cr
+#' Fabrice Rossi \email{fabrice.rossi@apiacoa.org}\cr
+#' Nathalie Vialaneix \email{nathalie.vialaneix@inrae.fr}
+#' 
+#' @seealso \code{\link{trainSOM}}
+#' 
+#' @examples 
+#' set.seed(2343)
+#' my.som <- trainSOM(x.data=iris[-100,1:4], dimension=c(5,5))
+#' predict(my.som, iris[100,1:4])
+
 predict.somRes <- function(object, x.new=NULL, ..., radius=0, 
                            tolerance=10^(-10)) {
   ## korresp
@@ -947,6 +1098,50 @@ predict.somRes <- function(object, x.new=NULL, ..., radius=0,
   return(winners)
 }
 
+#' @title Compute distances between prototypes
+#' @export
+#' @name protoDist
+#' @aliases protoDist.somRes
+#' 
+#' @description Compute distances, either between all prototypes 
+#' (\code{mode = "complete"}) or only between prototypes' neighbours 
+#' (\code{mode = "neighbors"}).
+#' 
+#' @param object a \code{somRes} object.
+#' @param mode Specifies which distances should be computed.
+#' @param \dots Not used.
+#' 
+#' @details When \code{mode="complete"}, distances between all prototypes are
+#' computed. When \code{mode="neighbors"}, distances are computed only between 
+#' the prototypes and their neighbors. If the data were preprocessed during the
+#' SOM training procedure, the distances are computed on the normalized values 
+#' of the prototypes.
+#' 
+#' @return When \code{mode = "complete"}, the function returns a square matrix 
+#' which dimensions are equal to the product of the grid dimensions.
+#' 
+#' When \code{mode = "neighbors"}, the function returns a list which length is 
+#' equal to the product of the grid dimensions; the length of each item is equal
+#' to the number of neighbors. Neurons are considered to have 8 neighbors at 
+#' most (\emph{i.e.}, two neurons are neighbors if they have a distance of type 
+#' 'maximum' which is equal to 1).
+#' 
+#' @author Madalina Olteanu \email{madalina.olteanu@univ-paris1.fr}\cr
+#' Nathalie Vialaneix \email{nathalie.vialaneix@inrae.fr}
+#' 
+#' @seealso \code{\link{trainSOM}}
+#' 
+#' @examples
+#' set.seed(2343)
+#' my.som <- trainSOM(x.data=iris[,1:4], dimension=c(5,5))
+#' protoDist(my.som)
+
+protoDist <- function(object, mode,...) {
+  UseMethod("protoDist")
+}
+
+#' @export
+
 protoDist.somRes <- function(object, mode=c("complete","neighbors"), ...) {
   mode <- match.arg(mode)
   complete <- (mode=="complete")
@@ -961,10 +1156,63 @@ protoDist.somRes <- function(object, mode=c("complete","neighbors"), ...) {
   return(distances)
 }
 
-protoDist <- function(object, mode,...) {
-  UseMethod("protoDist")
+#' @title Compute the projection of a graph on a grid
+#' @name projectIGraph
+#' @aliases projectIGraph.somRes
+#' @export
+#' 
+#' @description Compute the projection of a graph, provided as an 
+#' \code{\link[igraph]{igraph}} object, on the grid of the \code{somRes} object.
+#' 
+#' @param object a \code{somRes} object.
+#' @param init.graph an \link[igraph]{igraph} whose number of vertices is equal
+#' to the clustering length of the \code{somRes} object.
+#' @param \dots Not used.
+#' 
+#' @return The result is an \code{\link[igraph]{igraph}} which vertexes are the
+#' clusters (the clustering is thus understood as a vertex clustering) and the 
+#' edges are the counts of edges in the original graph between two vertices
+#' corresponding to the two clusters in the projected graph or, if 
+#' \code{init.graph} is a weighted graph, the sum of the weights between the 
+#' pairs of vertices corresponding to the two clusters.
+#' 
+#' The resulting igraph object's attributes are: \itemize{
+#'   \item the graph attribute \code{layout} which provides the layout of the 
+#'   projected graph according to the grid of the SOM;
+#'   \item the vertex attributes \code{name} and \code{size} which, respectively
+#'   are the vertex number on the grid and the number of vertexes included in 
+#'   the corresponding cluster;
+#'   \item the edge attribute \code{weight} which gives the number of edges (or 
+#'   the sum of the weights) between the vertexes of the two corresponding 
+#'   clusters.
+#' }
+#' 
+#' @author Madalina Olteanu \email{madalina.olteanu@univ-paris1.fr}\cr
+#' Nathalie Vialaneix \email{nathalie.vialaneix@inrae.fr}
+#' 
+#' @references 
+#' Olteanu M., Villa-Vialaneix N. (2015) Using SOMbrero for clustering and 
+#' visualizing graphs. \emph{Journal de la Société Française de Statistique},
+#' \strong{156}, 95-119.
+#' 
+#' @seealso \code{\link{projectIGraph.somSC}} which uses the results of a 
+#' super-clustering to obtain another projected graph. \code{\link{plot.somRes}} 
+#' with the option \code{type="graph"} or \code{\link{plot.somSC}} with the 
+#' option \code{type="projgraph"}.
+#' 
+#' @examples 
+#' data(lesmis)
+#' set.seed(7383)
+#' mis.som <- trainSOM(x.data=dissim.lesmis, type="relational", nb.save=10)
+#' proj.lesmis <- projectIGraph(mis.som, lesmis)
+#' \dontrun{plot(proj.lesmis)}
+
+projectIGraph <- function(object, init.graph, ...) {
+  UseMethod("projectIGraph")
 }
 
+#' @export
+
 projectIGraph.somRes <- function(object, init.graph, ...) {
   if (!is_igraph(init.graph)) {
     stop("'init.graph' must be an igraph object\n", call.=TRUE)
@@ -975,8 +1223,4 @@ projectIGraph.somRes <- function(object, init.graph, ...) {
   proj.graph <- projectGraph(init.graph, object$clustering,
                              object$parameters$the.grid$coord)
   return(proj.graph)
-}
-
-projectIGraph <- function(object, init.graph, ...) {
-  UseMethod("projectIGraph")
 }
\ No newline at end of file
